@@ -1,22 +1,26 @@
-from typing import TYPE_CHECKING, ClassVar
+from typing import TYPE_CHECKING, ClassVar, Generic, TypeVar
 
 from nonebot_plugin_alconna.uniseg import Receipt
 
-from ..constant import T_ForwardMsg, T_Message
+from ..typings import T_Message
 from .help_doc import descript
 from .interface import Interface
-from .utils import debug_log
+from .utils import debug_log, strict
 
 if TYPE_CHECKING:
     from .api import API
 
+_A = TypeVar("_A", bound="API")
 
-class User(Interface):
+
+class User(Generic[_A], Interface):
     __inst_name__: ClassVar[str] = "usr"
-    api: "API"
+    __slots__ = ("api", "uid")
+
+    api: _A
     uid: str
 
-    def __init__(self, api: "API", uid: str) -> None:
+    def __init__(self, api: _A, uid: str) -> None:
         super().__init__()
         self.api = api
         self.uid = uid
@@ -25,17 +29,10 @@ class User(Interface):
         description="向用户发送私聊消息",
         parameters=dict(msg="需要发送的消息"),
     )
+    @strict
     @debug_log
     async def send(self, msg: T_Message) -> Receipt:
         return await self.api.send_prv(self.uid, msg)
 
-    @descript(
-        description="向用户发送私聊合并转发消息",
-        parameters=dict(msgs="需要发送的消息列表"),
-    )
-    @debug_log
-    async def send_fwd(self, msgs: T_ForwardMsg) -> Receipt:
-        return await self.api.send_prv_fwd(self.uid, msgs)
-
-    def __repr__(self):
-        return f"{self.__class__.__name__}(user_id={self.uid})"
+    def __repr__(self) -> str:
+        return f"<{self.__class__.__name__} user_id={self.uid}>"
