@@ -2,7 +2,16 @@ import asyncio
 import functools
 import inspect
 from collections.abc import Callable, Coroutine
-from typing import Any, ClassVar, Generic, ParamSpec, TypeVar, cast, overload
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    ClassVar,
+    Generic,
+    ParamSpec,
+    TypeVar,
+    cast,
+    overload,
+)
 
 import nonebot
 from nonebot.adapters import Adapter, Bot, Message, MessageSegment
@@ -11,69 +20,75 @@ from nonebot_plugin_alconna.uniseg import Receipt, Segment, Target, UniMessage
 from nonebot_plugin_session import Session
 from typing_extensions import Self, TypeIs
 
-from ..constant import INTERFACE_EXPORT_METHOD, INTERFACE_METHOD_DESCRIPTION
 from ..typings import T_API_Result, T_Context, T_Message, generic_check_isinstance
 
+if TYPE_CHECKING:
+    from .help_doc import MethodDescription
+
+INTERFACE_EXPORT_METHOD = "__export_method__"
+INTERFACE_METHOD_DESCRIPTION = "__method_description__"
 WRAPPER_ASSIGNMENTS = (
     *functools.WRAPPER_ASSIGNMENTS,
     INTERFACE_EXPORT_METHOD,
     INTERFACE_METHOD_DESCRIPTION,
 )
 
-P = ParamSpec("P")
-R = TypeVar("R")
-T = TypeVar("T")
+_P = ParamSpec("_P")
+_R = TypeVar("_R")
+_T = TypeVar("_T")
 
 
-def export(call: Callable[P, R]) -> Callable[P, R]:
+def export(call: Callable[_P, _R]) -> Callable[_P, _R]:
     """将一个方法标记为导出函数"""
     setattr(call, INTERFACE_EXPORT_METHOD, True)
     return call
 
 
-class Coro(Coroutine[None, None, T], Generic[T]): ...
+def get_method_description(call: Callable[..., Any]) -> "MethodDescription | None":
+    return getattr(call, INTERFACE_METHOD_DESCRIPTION, None)
+
+
+class Coro(Coroutine[None, None, _T], Generic[_T]): ...
 
 
 @overload
-def debug_log(call: Callable[P, Coro[R]]) -> Callable[P, Coro[R]]: ...
+def debug_log(call: Callable[_P, Coro[_R]]) -> Callable[_P, Coro[_R]]: ...
 @overload
-def debug_log(call: Callable[P, R]) -> Callable[P, R]: ...
+def debug_log(call: Callable[_P, _R]) -> Callable[_P, _R]: ...
 
 
 def debug_log(
-    call: Callable[P, Coro[R]] | Callable[P, R],
-) -> Callable[P, Coro[R]] | Callable[P, R]:
+    call: Callable[_P, Coro[_R]] | Callable[_P, _R],
+) -> Callable[_P, Coro[_R]] | Callable[_P, _R]:
     if is_coroutine_callable(call):
-        call = cast(Callable[P, Coro[R]], call)
 
         async def wrapper(  # pyright: ignore[reportRedeclaration]
-            *args: P.args, **kwargs: P.kwargs
-        ) -> R:
+            *args: _P.args, **kwargs: _P.kwargs
+        ) -> _R:
             nonebot.logger.debug(f"{call.__name__}: args={args!r}, kwargs={kwargs!r}")
-            return await call(*args, **kwargs)
+            return await cast(Callable[_P, Coro[_R]], call)(*args, **kwargs)
 
     else:
-        call = cast(Callable[P, R], call)
 
-        def wrapper(*args: P.args, **kwargs: P.kwargs) -> R:
+        def wrapper(*args: _P.args, **kwargs: _P.kwargs) -> _R:
             nonebot.logger.debug(f"{call.__name__}: args={args!r}, kwargs={kwargs!r}")
-            return call(*args, **kwargs)
+            return cast(Callable[_P, _R], call)(*args, **kwargs)
 
     return cast(
-        Callable[P, Coro[R]] | Callable[P, R],
+        Callable[_P, Coro[_R]] | Callable[_P, _R],
         functools.update_wrapper(wrapper, call, assigned=WRAPPER_ASSIGNMENTS),
     )
 
 
 @overload
-def strict(call: Callable[P, Coro[R]]) -> Callable[P, Coro[R]]: ...
+def strict(call: Callable[_P, Coro[_R]]) -> Callable[_P, Coro[_R]]: ...
 @overload
-def strict(call: Callable[P, R]) -> Callable[P, R]: ...
+def strict(call: Callable[_P, _R]) -> Callable[_P, _R]: ...
 
 
 def strict(
-    call: Callable[P, Coro[R]] | Callable[P, R],
-) -> Callable[P, Coro[R]] | Callable[P, R]:
+    call: Callable[_P, Coro[_R]] | Callable[_P, _R],
+) -> Callable[_P, Coro[_R]] | Callable[_P, _R]:
     sig = inspect.signature(call)
     params = sig.parameters.copy()
     params.pop("cls", None)
@@ -100,19 +115,19 @@ def strict(
     if is_coroutine_callable(call):
 
         async def wrapper(  # pyright: ignore[reportRedeclaration]
-            *args: P.args, **kwargs: P.kwargs
-        ) -> R:
+            *args: _P.args, **kwargs: _P.kwargs
+        ) -> _R:
             check_args(args, kwargs)
-            return await cast(Callable[P, Coro[R]], call)(*args, **kwargs)
+            return await cast(Callable[_P, Coro[_R]], call)(*args, **kwargs)
 
     else:
 
-        def wrapper(*args: P.args, **kwargs: P.kwargs) -> R:
+        def wrapper(*args: _P.args, **kwargs: _P.kwargs) -> _R:
             check_args(args, kwargs)
-            return cast(Callable[P, R], call)(*args, **kwargs)
+            return cast(Callable[_P, _R], call)(*args, **kwargs)
 
     return cast(
-        Callable[P, Coro[R]] | Callable[P, R],
+        Callable[_P, Coro[_R]] | Callable[_P, _R],
         functools.update_wrapper(wrapper, call, assigned=WRAPPER_ASSIGNMENTS),
     )
 
@@ -318,4 +333,4 @@ async def _on_driver_startup() -> None:
 
 def export_message(adapter: Adapter) -> dict[str, Any]:
     m, ms = _get_msg_cls(adapter)
-    return {"Messae": m, "MessageSegment": ms}
+    return {"Message": m, "MessageSegment": ms}
