@@ -312,8 +312,11 @@ async def test_event_reply_message_2(app: App) -> None:
                 nickname="test",
                 role="member",
             ),
-            message=reply_msg.extract_plain_text(),  # pyright: ignore[reportArgumentType]
+            message=reply_msg,
         )
+        event.reply.message = (
+            reply_msg.extract_plain_text()
+        )  # pyright:ignore[reportAttributeAccessIssue]
         state = {}
         stack = AsyncExitStack()
         with ensure_context(bot, event):
